The posterior covariance matrix of the variables d (basic treatment
effect parameters) and delta (shrunken random effects estimates for
each study).
SocAnx.post.covAn object of class matrix (inherits from array) with 186 rows and 186 columns.
Mayo-Wilson E, Dias S, Mavranezouli I, Kew K, Clark DM, Ades AE, et al. Psychological and pharmacological interventions for social anxiety disorder in adults: a systematic review and network meta-analysis. Lancet Psychiatry 2014;1:368-76. http://dx.doi.org/10.1016/S2215-0366(14)70329-3